@@ -40,6 +40,11 @@ ConfirmationsSettingsPage::ConfirmationsSettingsPage(QWidget* parent) :
     m_confirmMoveToTrash(nullptr),
     m_confirmEmptyTrash(nullptr),
     m_confirmDelete(nullptr),
+
+#ifdef HAVE_TERMINAL
+    m_confirmClosingTerminalRunningProgram(nullptr),
+#endif
+
     m_confirmClosingMultipleTabs(nullptr)
 {
     QVBoxLayout* topLayout = new QVBoxLayout(this);
@@ -62,6 +67,11 @@ ConfirmationsSettingsPage::ConfirmationsSettingsPage(QWidget* parent) :
     m_confirmClosingMultipleTabs = new QCheckBox(i18nc("@option:check Ask for confirmation in Dolphin when",
                                                        "Closing windows with multiple tabs"), this);
 
+#ifdef HAVE_TERMINAL
+    m_confirmClosingTerminalRunningProgram = new QCheckBox(i18nc("@option:check Ask for confirmation when",
+                                                       "Closing windows with a program running in the Terminal panel"), this);
+#endif
+
     topLayout->addWidget(confirmLabelKde);
     topLayout->addWidget(m_confirmMoveToTrash);
     topLayout->addWidget(m_confirmEmptyTrash);
@@ -70,6 +80,11 @@ ConfirmationsSettingsPage::ConfirmationsSettingsPage(QWidget* parent) :
     topLayout->addSpacing(Dolphin::VERTICAL_SPACER_HEIGHT);
     topLayout->addWidget(confirmLabelDolphin);
     topLayout->addWidget(m_confirmClosingMultipleTabs);
+
+#ifdef HAVE_TERMINAL
+    topLayout->addWidget(m_confirmClosingTerminalRunningProgram);
+#endif
+
     topLayout->addStretch();
 
     loadSettings();
@@ -79,6 +94,10 @@ ConfirmationsSettingsPage::ConfirmationsSettingsPage(QWidget* parent) :
     connect(m_confirmDelete, &QCheckBox::toggled, this, &ConfirmationsSettingsPage::changed);
     connect(m_confirmScriptExecution, &QCheckBox::toggled, this, &ConfirmationsSettingsPage::changed);
     connect(m_confirmClosingMultipleTabs, &QCheckBox::toggled, this, &ConfirmationsSettingsPage::changed);
+
+#ifdef HAVE_TERMINAL
+    connect(m_confirmClosingTerminalRunningProgram, &QCheckBox::toggled, this, &ConfirmationsSettingsPage::changed);
+#endif
 }
 
 ConfirmationsSettingsPage::~ConfirmationsSettingsPage()
@@ -103,6 +122,11 @@ void ConfirmationsSettingsPage::applySettings()
 
     GeneralSettings* settings = GeneralSettings::self();
     settings->setConfirmClosingMultipleTabs(m_confirmClosingMultipleTabs->isChecked());
+
+#ifdef HAVE_TERMINAL
+    settings->setConfirmClosingTerminalRunningProgram(m_confirmClosingTerminalRunningProgram->isChecked());
+#endif
+
     settings->save();
 }
 
@@ -132,5 +156,9 @@ void ConfirmationsSettingsPage::loadSettings()
     m_confirmScriptExecution->setChecked(value == QLatin1String("alwaysAsk"));
 
     m_confirmClosingMultipleTabs->setChecked(GeneralSettings::confirmClosingMultipleTabs());
+
+#ifdef HAVE_TERMINAL
+    m_confirmClosingTerminalRunningProgram->setChecked(GeneralSettings::confirmClosingTerminalRunningProgram());
+#endif
 }
 
